HarnessError

Enum HarnessError 

pub enum HarnessError {
Show 29 variants MissingAgent, MissingFlagValue { flag: String, }, UnknownFlag { flag: String, }, ConfigRead { path: PathBuf, source: Error, }, ConfigParse { path: PathBuf, source: Box<Error>, }, ConfigInvalid { path: PathBuf, message: String, }, CapsuleSerialize { source: Error, }, CapsuleWrite { path: PathBuf, source: Error, }, MissingCapsulePath, DraftSerialize { source: Error, }, DraftWrite { path: PathBuf, source: Error, }, CheckpointEmpty, CheckpointSessionDraftsDirMissing, NativeMemoryRead { path: PathBuf, source: Error, }, Librarian { source: LibrarianError, }, RemoteSyncUnavailable { message: String, }, RemoteSyncIo { path: PathBuf, source: Error, }, RemoteSyncConflict { path: PathBuf, message: String, }, MemoryUnavailable { message: String, }, RemoteGit { command: String, message: String, }, RemoteSyncLock { source: WorkspaceLockError, }, RemoteSyncVerify { path: PathBuf, source: Box<VerifyError>, }, RemoteSyncIntegrity { path: PathBuf, message: String, }, RemoteDrillIntegrity { path: PathBuf, message: String, }, RemoteDrillVerify { path: PathBuf, source: Box<VerifyError>, }, RemoteDrillStore { path: PathBuf, source: Box<StoreError>, }, RemoteDrillRead { source: Box<ReadError>, }, WorkspaceLogPrepare { path: PathBuf, source: Error, }, Spawn { program: String, source: Error, },
}
Errors returned by harness argument parsing or child launch.

Variants



MissingAgent

No child agent was supplied.



MissingFlagValue

A Mimir flag requiring a value was the last argument.

Fields

flag: String

Flag that requires a following value.



UnknownFlag

A Mimir flag before the agent name is not supported.

Fields

flag: String

Unsupported flag.



ConfigRead

Explicit config file path could not be read.

Fields

path: PathBuf

Config path that could not be read.

source: Error

Underlying filesystem error.



ConfigParse

Config TOML could not be parsed.

Fields

path: PathBuf

Config path that failed TOML parsing.

source: Box<Error>

Underlying TOML parser error.



ConfigInvalid

Config TOML used the wrong value type.

Fields

path: PathBuf

Config path that failed validation.

message: String

Human-readable validation message.



CapsuleSerialize

Session capsule could not be serialized.

Fields

source: Error

Underlying JSON serializer error.



CapsuleWrite

Session capsule could not be written.

Fields

path: PathBuf

Capsule path that could not be written.

source: Error

Underlying filesystem error.



MissingCapsulePath

Launch plan was not fully prepared before writing session artifacts.



DraftSerialize

Post-session draft could not be serialized.

Fields

source: Error

Underlying JSON serializer error.



DraftWrite

Post-session draft could not be written.

Fields

path: PathBuf

Draft path or lifecycle directory that could not be written.

source: Error

Underlying filesystem error.



CheckpointEmpty

Checkpoint helper was invoked without a note body.



CheckpointSessionDraftsDirMissing

Checkpoint helper was invoked outside a wrapped session.



NativeMemoryRead

Native memory source could not be read.

Fields

path: PathBuf

Native memory file or directory path that could not be read.

source: Error

Underlying filesystem error.



Librarian

Librarian handoff could not be completed.

Fields

source: LibrarianError

Underlying librarian error.



RemoteSyncUnavailable

Remote sync could not be prepared or is unsupported.

Fields

message: String

Human-readable reason.



RemoteSyncIo

Remote sync filesystem operation failed.

Fields

path: PathBuf

Path involved in the failing operation.

source: Error

Underlying filesystem error.



RemoteSyncConflict

Remote sync found conflicting local and remote state.

Fields

path: PathBuf

Path whose content conflicts with its counterpart.

message: String

Human-readable conflict description.



MemoryUnavailable

Operator memory command could not complete.

Fields

message: String

Human-readable reason.



RemoteGit

Git failed while preparing or publishing the recovery mirror.

Fields

command: String

Command description.

message: String

Captured stderr/stdout summary.



RemoteSyncLock

Remote sync could not acquire the workspace lock.

Fields

source: WorkspaceLockError

Underlying workspace-lock error.



RemoteSyncVerify

Remote sync could not verify a canonical log before/after copy.

Fields

path: PathBuf

Canonical log path checked by remote sync.

source: Box<VerifyError>

Underlying verify error.



RemoteSyncIntegrity

Remote sync found corrupt canonical-log bytes.

Fields

path: PathBuf

Canonical log path checked by remote sync.

message: String

Human-readable failure reason.



RemoteDrillIntegrity

Restore drill integrity verification failed.

Fields

path: PathBuf

Local canonical log path checked by the drill.

message: String

Human-readable failure reason.



RemoteDrillVerify

Restore drill could not verify the local canonical log.

Fields

path: PathBuf

Local canonical log path checked by the drill.

source: Box<VerifyError>

Underlying verify error.



RemoteDrillStore

Restore drill could not reopen the restored store.

Fields

path: PathBuf

Local canonical log path reopened by the drill.

source: Box<StoreError>

Underlying store error.



RemoteDrillRead

Restore drill read-path sanity query failed.

Fields

source: Box<ReadError>

Underlying read-path error.



WorkspaceLogPrepare

Workspace log parent directory could not be prepared.

Fields

path: PathBuf

Directory that could not be created.

source: Error

Underlying filesystem error.



Spawn

The child process could not be launched.

Fields

program: String

Child executable name or path.

source: Error

Underlying process-spawn error.