pub enum RemoteSyncDirection {
Push,
Pull,
}Expand description
Explicit remote sync direction for governed memory recovery state.
Variants
Push
Copy local governed memory state into the configured Git remote.
Pull
Copy configured Git remote state back into local Mimir storage.